Exception: RubyPyError
- Inherits:
-
Exception
- Object
- Exception
- RubyPyError
- Defined in:
- ext/rubypython_bridge/rp_error.c
Overview
Used to pass error information back into Ruby should an error occur in the embedded Python interpreter.