Method: RubyPython::RubyPyProxy#initialize
- Defined in:
- lib/rubypython/rubypyproxy.rb
#initialize(pObject) ⇒ RubyPyProxy
Creates a Python proxy for the provided Ruby object.
Only the following Ruby types can be represented in Python:
-
String
-
Array
-
Hash
-
Fixnum
-
Bignum
-
Float
-
Symbol (as a String)
-
Proc
-
Method
-
true(as True) -
false(as False) -
nil(as None)
82 83 84 85 86 87 88 |
# File 'lib/rubypython/rubypyproxy.rb', line 82 def initialize(pObject) if pObject.kind_of? PyObject @pObject = pObject else @pObject = PyObject.new pObject end end |