Module: RubyPython::LegacyMode
- Defined in:
- lib/rubypython/legacy.rb
Overview
A quick way to activate legacy mode for your project. Requiring ‘rubypython/legacy’ automatically activates legacy_mode as described in the documentation for RubyPython. If you wish to run your project in legacy mode you can require ‘rubypython/legacy’ instead of ‘rubypython’
Class Method Summary collapse
Class Method Details
.setup_legacy ⇒ Object
30 31 32 |
# File 'lib/rubypython/legacy.rb', line 30 def setup_legacy RubyPython.legacy_mode = true end |
.teardown_legacy ⇒ Object
34 35 36 |
# File 'lib/rubypython/legacy.rb', line 34 def teardown_legacy RubyPython.legacy_mode = false end |